PyXMake Developer Guide: PyXMake Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Namespaces | Variables
PyXMake Namespace Reference

PyXMake package for programmable build events on Linux and Windows. More...

## Namespaces
| Build
| Module containing all relevant modules and scripts associated with the building process.
| Tools
| Module containing basic functionalities defined for convenience.
| VTL
| Module containing virtual testing & benchmark scripts.

## Variables
| PyXMakePath = os.path.dirname(os.path.abspath(__file__))
| Absolute system path to PyXMake. More...

## Detailed Description

PyXMake package for programmable build events on Linux and Windows.

    PyXMake is a cross-plattform build tool for source files using either Intel Fortran,
    Py2X, a SSH connection or Doxygen to build a library or to automatically create a
    documentation.

    @note: PyXMake.__init__()
    Created on 20.03.2018

    @version: 1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          -

    @change:
          -

    @contributors:
          Falk Heinecke
          Sebastian Freund
          Andreas Schuster

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

Authors
  Marc Garbade, Falk Heinecke, Sebastian Freund, Andreas Schuster

Date
  20.03.2018

Notes/Changes
  - Added documentation // mg 29.03.2018

## Variable Documentation

## ◆ PyXMakePath

PyXMake.PyXMakePath = os.path.dirname(os.path.abspath(__file__))

Absolute system path to PyXMake.

Definition at line 43 of file __init__.py.